==> tablefilter-swing-3.1.0-sources.jar: net/coderazzi/filters/gui/TableFilterHeaderBeanInfo.java <==
/**
 * Author:  Luis M Pena  ( lu@coderazzi.net )
 * License: MIT License
 *
 * Copyright (c) 2007 Luis M. Pena  -  lu@coderazzi.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.coderazzi.filters.gui;

import java.beans.BeanDescriptor;
import java.beans.SimpleBeanInfo;

public class TableFilterHeaderBeanInfo extends SimpleBeanInfo{
    
    @Override
	public BeanDescriptor getBeanDescriptor() {
        BeanDescriptor desc = new BeanDescriptor(TableFilterHeader.class);
        desc.setValue("isContainer", Boolean.FALSE);
        return desc;
    }
    
    @Override
	public java.awt.Image getIcon(int iconKind) {
        return loadImage("/net/coderazzi/filters/resources/tableFilterHeader.png");
    }

}

==> tablefilter-swing-5.5.4-sources.jar: net/coderazzi/filters/gui/TableFilterHeaderBeanInfo.java <==
/**
 * Author:  Luis M Pena  ( lu@coderazzi.net )
 * License: MIT License
 *
 * Copyright (c) 2007 Luis M. Pena  -  lu@coderazzi.net
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package net.coderazzi.filters.gui;

import java.beans.BeanDescriptor;
import java.beans.SimpleBeanInfo;


public class TableFilterHeaderBeanInfo extends SimpleBeanInfo {

    @Override public BeanDescriptor getBeanDescriptor() {
        BeanDescriptor desc = new BeanDescriptor(TableFilterHeader.class);
        desc.setValue("isContainer", Boolean.FALSE);

        return desc;
    }

    @Override public java.awt.Image getIcon(int iconKind) {
        return loadImage(
                "/net/coderazzi/filters/resources/tableFilterHeader.png");
    }

}
